camelot_admin — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- bin »

# camelot_admin

camelot_admin is a tool to assist in the creation and development of Camelot projects. Use this application without any options to start a GUI to create a new Camelot project.

`startproject`

  Starts a new project, use startproject project_name.

`makemessages`

  Outputs a message file with all field names of all entities. This command requires settings.py of the project to be in the PYTHONPATH

`apidoc`

  Extract API documentation from source code, to be used with sphinx.

`license_update`

  Change the license header of a project, use license_update project_directory license_file

`to_pyside`

  Takes a folder with PyQt4 source code and translates it to PySide source code. A directory to_pyside will be created containing the output of the translation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- bin »

Comments
blog comments powered by Disqus